@@ -1,5 +1,5 @@
 /* d30v.h -- Header file for D30V opcode table
-   Copyright (C) 1997-2020 Free Software Foundation, Inc.
+   Copyright (C) 1997-2021 Free Software Foundation, Inc.
    Written by Martin Hunt (hunt@cygnus.com), Cygnus Solutions
 
    This file is part of GDB, GAS, and the GNU binutils.
@@ -33,7 +33,7 @@ struct pd_reg
 {
   char *name;		/* name to recognize */
   char *pname;		/* name to print for this register */
-  int value;
+  unsigned int value;
 };
 
 extern const struct pd_reg pre_defined_registers[];
