@@ -56,7 +56,7 @@ extern int errno;
 #endif
 
 /* Report plugin symbols.  */
-bfd_boolean report_plugin_symbols;
+bool report_plugin_symbols;
 
 /* The suffix to append to the name of the real (claimed) object file
    when generating a dummy BFD to hold the IR symbols sent from the
@@ -88,7 +88,7 @@ typedef struct plugin
   ld_plugin_all_symbols_read_handler all_symbols_read_handler;
   ld_plugin_cleanup_handler cleanup_handler;
   /* TRUE if the cleanup handlers have been called.  */
-  bfd_boolean cleanup_done;
+  bool cleanup_done;
 } plugin_t;
 
 typedef struct view_buffer
@@ -106,7 +106,7 @@ typedef struct plugin_input_file
   view_buffer_t view_buffer;
   char *name;
   int fd;
-  bfd_boolean use_mmap;
+  bool use_mmap;
   off_t offset;
   off_t filesize;
 } plugin_input_file_t;
@@ -130,7 +130,7 @@ static plugin_t *called_plugin = NULL;
 static const char *error_plugin = NULL;
 
 /* State of linker "notice" interface before we poked at it.  */
-static bfd_boolean orig_notice_all;
+static bool orig_notice_all;
 
 /* Original linker callbacks, and the plugin version.  */
 static const struct bfd_link_callbacks *orig_callbacks;
@@ -138,7 +138,7 @@ static struct bfd_link_callbacks plugin_callbacks;
 
 /* Set at all symbols read time, to avoid recursively offering the plugin
    its own newly-added input files and libs to claim.  */
-bfd_boolean no_more_claiming = FALSE;
+bool no_more_claiming = false;
 
 #if HAVE_MMAP && HAVE_GETPAGESIZE
 /* Page size used by mmap.  */
@@ -171,10 +171,10 @@ static const enum ld_plugin_tag tv_header_tags[] =
 static const size_t tv_header_size = ARRAY_SIZE (tv_header_tags);
 
 /* Forward references.  */
-static bfd_boolean plugin_notice (struct bfd_link_info *,
-				  struct bfd_link_hash_entry *,
-				  struct bfd_link_hash_entry *,
-				  bfd *, asection *, bfd_vma, flagword);
+static bool plugin_notice (struct bfd_link_info *,
+			   struct bfd_link_hash_entry *,
+			   struct bfd_link_hash_entry *,
+			   bfd *, asection *, bfd_vma, flagword);
 
 static bfd_cleanup plugin_object_p (bfd *);
 
@@ -220,7 +220,7 @@ set_plugin_error (const char *plugin)
 }
 
 /* Test if an error occurred.  */
-static bfd_boolean
+static bool
 plugin_error_p (void)
 {
   return error_plugin != NULL;
@@ -309,7 +309,7 @@ static bfd *
 plugin_get_ir_dummy_bfd (const char *name, bfd *srctemplate)
 {
   bfd *abfd;
-  bfd_boolean bfd_plugin_target;
+  bool bfd_plugin_target;
 
   bfd_use_reserved_id = 1;
   bfd_plugin_target = bfd_plugin_target_p (srctemplate->xvec);
@@ -343,7 +343,7 @@ plugin_get_ir_dummy_bfd (const char *name, bfd *srctemplate)
 }
 
 /* Check if the BFD passed in is an IR dummy object file.  */
-static inline bfd_boolean
+static inline bool
 is_ir_dummy_bfd (const bfd *abfd)
 {
   /* ABFD can sometimes legitimately be NULL, e.g. when called from one
@@ -563,7 +563,7 @@ get_view (const void *handle, const void **viewp)
   buffer = mmap (NULL, size, PROT_READ, MAP_PRIVATE, input->fd, offset);
   if (buffer != MAP_FAILED)
     {
-      input->use_mmap = TRUE;
+      input->use_mmap = true;
 # if HAVE_GETPAGESIZE
       buffer += bias;
 # endif
@@ -573,7 +573,7 @@ get_view (const void *handle, const void **viewp)
     {
       char *p;
 
-      input->use_mmap = FALSE;
+      input->use_mmap = false;
 
       if (lseek (input->fd, offset, SEEK_SET) < 0)
 	return LDPS_ERR;
@@ -621,12 +621,12 @@ release_input_file (const void *handle)
 
 /* Return TRUE if a defined symbol might be reachable from outside the
    universe of claimed objects.  */
-static inline bfd_boolean
+static inline bool
 is_visible_from_outside (struct ld_plugin_symbol *lsym,
 			 struct bfd_link_hash_entry *blhe)
 {
   if (bfd_link_relocatable (&link_info))
-    return TRUE;
+    return true;
   if (blhe->non_ir_ref_dynamic
       || link_info.export_dynamic
       || bfd_link_dll (&link_info))
@@ -634,9 +634,9 @@ is_visible_from_outside (struct ld_plugin_symbol *lsym,
       /* Check if symbol is hidden by version script.  */
       if (bfd_hide_sym_by_version (link_info.version_info,
 				   blhe->root.string))
-	return FALSE;
+	return false;
       /* Only ELF symbols really have visibility.  */
-      if (bfd_get_flavour (link_info.output_bfd) == bfd_target_elf_flavour)
+      if (is_elf_hash_table (link_info.hash))
 	{
 	  struct elf_link_hash_entry *el = (struct elf_link_hash_entry *)blhe;
 	  int vis = ELF_ST_VISIBILITY (el->other);
@@ -656,7 +656,7 @@ is_visible_from_outside (struct ld_plugin_symbol *lsym,
 	      || lsym->visibility == LDPV_PROTECTED);
     }
 
-  return FALSE;
+  return false;
 }
 
 /* Return LTO kind string name that corresponds to IDX enum value.  */
@@ -743,7 +743,7 @@ get_symbols (const void *handle, int nsyms, struct ld_plugin_symbol *syms,
       int res;
       struct bfd_link_hash_entry *h
 	= bfd_link_hash_lookup (link_info.hash, syms[n].name,
-				FALSE, FALSE, TRUE);
+				false, false, true);
       enum { wrap_none, wrapper, wrapped } wrap_status = wrap_none;
 
       if (syms[n].def != LDPK_UNDEF && syms[n].def != LDPK_WEAKUNDEF)
@@ -762,7 +762,7 @@ get_symbols (const void *handle, int nsyms, struct ld_plugin_symbol *syms,
 	{
 	  blhe = bfd_wrapped_link_hash_lookup (link_info.output_bfd,
 					       &link_info, syms[n].name,
-					       FALSE, FALSE, TRUE);
+					       false, false, true);
 	  /* Check if a symbol is a wrapped symbol.  */
 	  if (blhe && blhe != h)
 	    wrap_status = wrapped;
@@ -922,7 +922,7 @@ static enum ld_plugin_status
 set_extra_library_path (const char *path)
 {
   ASSERT (called_plugin);
-  ldfile_add_library_path (xstrdup (path), FALSE);
+  ldfile_add_library_path (xstrdup (path), false);
   return LDPS_OK;
 }
 
@@ -936,14 +936,14 @@ message (int level, const char *format, ...)
   switch (level)
     {
     case LDPL_INFO:
-      vfinfo (stdout, format, args, FALSE);
+      vfinfo (stdout, format, args, false);
       putchar ('\n');
       break;
     case LDPL_WARNING:
       {
 	char *newfmt = concat (_("%P: warning: "), format, "\n",
 			       (const char *) NULL);
-	vfinfo (stdout, newfmt, args, TRUE);
+	vfinfo (stdout, newfmt, args, true);
 	free (newfmt);
       }
       break;
@@ -955,7 +955,7 @@ message (int level, const char *format, ...)
 			       _("%P: error: "), format, "\n",
 			       (const char *) NULL);
 	fflush (stdout);
-	vfinfo (stderr, newfmt, args, TRUE);
+	vfinfo (stderr, newfmt, args, true);
 	fflush (stderr);
 	free (newfmt);
       }
@@ -1115,8 +1115,8 @@ plugin_load_plugins (void)
   orig_callbacks = link_info.callbacks;
   plugin_callbacks = *orig_callbacks;
   plugin_callbacks.notice = &plugin_notice;
-  link_info.notice_all = TRUE;
-  link_info.lto_plugin_active = TRUE;
+  link_info.notice_all = true;
+  link_info.lto_plugin_active = true;
   link_info.callbacks = &plugin_callbacks;
 
   register_ld_plugin_object_p (plugin_object_p);
@@ -1131,7 +1131,7 @@ static int
 plugin_call_claim_file (const struct ld_plugin_input_file *file, int *claimed)
 {
   plugin_t *curplug = plugins_list;
-  *claimed = FALSE;
+  *claimed = false;
   while (curplug && !*claimed)
     {
       if (curplug->claim_file_handler)
@@ -1215,7 +1215,7 @@ plugin_object_p (bfd *ibfd)
   input->view_buffer.filesize = 0;
   input->view_buffer.offset = 0;
   input->fd = file.fd;
-  input->use_mmap = FALSE;
+  input->use_mmap = false;
   input->offset = file.offset;
   input->filesize = file.filesize;
   input->name = plugin_strdup (abfd, bfd_get_filename (ibfd));
@@ -1301,7 +1301,7 @@ plugin_call_all_symbols_read (void)
   plugin_t *curplug = plugins_list;
 
   /* Disable any further file-claiming.  */
-  no_more_claiming = TRUE;
+  no_more_claiming = true;
 
   while (curplug)
     {
@@ -1329,7 +1329,7 @@ plugin_call_cleanup (void)
       if (curplug->cleanup_handler && !curplug->cleanup_done)
 	{
 	  enum ld_plugin_status rv;
-	  curplug->cleanup_done = TRUE;
+	  curplug->cleanup_done = true;
 	  called_plugin = curplug;
 	  rv = (*curplug->cleanup_handler) ();
 	  called_plugin = NULL;
@@ -1349,7 +1349,7 @@ plugin_call_cleanup (void)
    non_ir_ref_dynamic as appropriate.  We have to notice_all symbols,
    because we won't necessarily know until later which ones will be
    contributed by IR files.  */
-static bfd_boolean
+static bool
 plugin_notice (struct bfd_link_info *info,
 	       struct bfd_link_hash_entry *h,
 	       struct bfd_link_hash_entry *inh,
@@ -1363,7 +1363,7 @@ plugin_notice (struct bfd_link_info *info,
   if (h != NULL)
     {
       bfd *sym_bfd;
-      bfd_boolean ref = FALSE;
+      bool ref = false;
 
       if (h->type == bfd_link_hash_warning)
 	h = h->u.i.link;
@@ -1383,13 +1383,13 @@ plugin_notice (struct bfd_link_info *info,
 	      || inh->type == bfd_link_hash_new)
 	    {
 	      if ((abfd->flags & DYNAMIC) == 0)
-		inh->non_ir_ref_regular = TRUE;
+		inh->non_ir_ref_regular = true;
 	      else
-		inh->non_ir_ref_dynamic = TRUE;
+		inh->non_ir_ref_dynamic = true;
 	    }
 
 	  if (h->type != bfd_link_hash_new)
-	    ref = TRUE;
+	    ref = true;
 	}
 
       /* Nothing to do here for warning symbols.  */
@@ -1409,7 +1409,7 @@ plugin_notice (struct bfd_link_info *info,
 	       && (h->u.undef.abfd == NULL
 		   || (h->u.undef.abfd->flags & BFD_PLUGIN) != 0))
 	     h->u.undef.abfd = abfd;
-	  ref = TRUE;
+	  ref = true;
 	}
 
 
@@ -1425,7 +1425,7 @@ plugin_notice (struct bfd_link_info *info,
 	      h->type = bfd_link_hash_undefweak;
 	      h->u.undef.abfd = sym_bfd;
 	    }
-	  ref = TRUE;
+	  ref = true;
 	}
 
       /* Otherwise, it must be a new def.
@@ -1453,9 +1453,9 @@ plugin_notice (struct bfd_link_info *info,
       if (ref)
 	{
 	  if ((abfd->flags & DYNAMIC) == 0)
-	    h->non_ir_ref_regular = TRUE;
+	    h->non_ir_ref_regular = true;
 	  else
-	    h->non_ir_ref_dynamic = TRUE;
+	    h->non_ir_ref_dynamic = true;
 	}
     }
 
@@ -1464,9 +1464,9 @@ plugin_notice (struct bfd_link_info *info,
       || orig_notice_all
       || (info->notice_hash != NULL
 	  && bfd_hash_lookup (info->notice_hash, orig_h->root.string,
-			      FALSE, FALSE) != NULL))
+			      false, false) != NULL))
     return (*orig_callbacks->notice) (info, orig_h, inh,
 				      abfd, section, value, flags);
-  return TRUE;
+  return true;
 }
 #endif /* BFD_SUPPORTS_PLUGINS */
